
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.029.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Perl extension for scrubbing/sanitizing html",
  "dist_author" => [
    "Ruslan Zakirov <Ruslan.Zakirov\@gmail.com>",
    "Nigel Metheringham <nigelm\@cpan.org>",
    "D. H. <podmaster\@cpan.org>"
  ],
  "dist_name" => "HTML-Scrubber",
  "dist_version" => "0.12",
  "license" => "perl",
  "module_name" => "HTML::Scrubber",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "HTML::Entities" => 0,
    "HTML::Parser" => "3.47",
    "Scalar::Util" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "Carp" => 0,
    "File::Spec" => 0,
    "File::Temp" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test" => 0,
    "Test::CPAN::Meta" => 0,
    "Test::EOL" => 0,
    "Test::Memory::Cycle" => 0,
    "Test::More" => "0.94",
    "Test::NoTabs" => 0,
    "perl" => "5.006",
    "utf8" => 0
  }
);


my %fallback_build_requires = (
  "Carp" => 0,
  "File::Spec" => 0,
  "File::Temp" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Test" => 0,
  "Test::CPAN::Meta" => 0,
  "Test::EOL" => 0,
  "Test::Memory::Cycle" => 0,
  "Test::More" => "0.94",
  "Test::NoTabs" => 0,
  "perl" => "5.006",
  "utf8" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
